@@ -20,6 +20,7 @@ from django.core.urlresolvers import reverse
 from django.db import models, connection
 from django.db.models import Count
 from django.db.models.fields.files import ImageFieldFile
+from django.db.models.query import EmptyQuerySet
 from decimal import Decimal
 from django.utils.translation import ugettext_lazy as _
 from django.utils.safestring import mark_safe
@@ -586,16 +587,27 @@ def _radians(degrees):
 class AggregateResultCount:
     """ This helper class makes it easier to write templates that display
     pie charts. """
-    def __init__(self, survey, field, request_data, surveyreport=None):
-        self.answer_set = field.public_answers.values(field.value_column)
-        self.answer_set = self.answer_set.annotate(count=Count("id"))
-        self.answer_set = extra_from_filters(self.answer_set,
-                                             "submission_id",
-                                             survey,
-                                             request_data)
-        if surveyreport and surveyreport.featured:
-            self.answer_set = self.answer_set.filter(submission__featured=True)
+    def __init__(self,
+                 survey,
+                 field,
+                 request_data,
+                 surveyreport=None,
+                 is_staff=False):
+        self.answer_set = field.answer_set.none()
         self.answer_value_lookup = {}
+        if is_staff or field.answer_is_public:
+            self.answer_set = field.public_answers
+            if is_staff:
+                self.answer_set = field.answer_set
+            self.answer_set = self.answer_set.values(field.value_column)
+            self.answer_set = self.answer_set.annotate(count=Count("id"))
+            self.answer_set = extra_from_filters(self.answer_set,
+                                                 "submission_id",
+                                                 survey,
+                                                 request_data)
+            if surveyreport and surveyreport.featured:
+                self.answer_set = self.answer_set.filter(
+                    submission__featured=True)
         for answer in self.answer_set:
             text = fill(u"%s" % answer[field.value_column], 30)
             if answer["count"]:
@@ -735,8 +747,13 @@ class Submission(models.Model):
             return v
         if not answer_lookup:
             answer_lookup = get_all_answers([self], include_private_questions)
-        return_value = dict(data=dict((a.question.fieldname, to_json(a.value))
-                                      for a in answer_lookup.get(self.pk, [])),
+        data = {}
+        for a in answer_lookup.get(self.pk, []):
+            if a.question.option_type == OPTION_TYPE_CHOICES.BOOL_LIST:
+                data[a.value] = True
+            else:
+                data[a.question.fieldname] = to_json(a.value)
+        return_value = dict(data=data,
                             survey=self.survey.slug,
                             submitted_at=self.submitted_at,
                             featured=self.featured,
@@ -766,6 +783,9 @@ class Submission(models.Model):
     def email(self):
         return self.get_answer_dict().get('email', '')
 
+    def __unicode__(self):
+        return u"%s Submission" % self.survey.title
+
 
 class Answer(models.Model):
     submission = models.ForeignKey(Submission)
