@@ -273,7 +273,7 @@ def submissions(request, format):
     out:
     1. Enable filters on your survey and the questions you want to filter on.
     2. Go to the report page and fill out the filters you want.
-    3. Click Submit. 
+    3. Click Submit.
     4. Examine the query string of the page you end up on and note which
         parameters are filled out. Use those same parameters here. """
     format = format.lower()
@@ -426,6 +426,10 @@ def submissions(request, format):
 
 
 def _encode(possible):
+    if possible is True:
+        return 1
+    elif possible is False:
+        return 0
     return datetime_to_string(possible) or possible
 
 
@@ -518,20 +522,21 @@ def _survey_report(request, slug, report, page, templates):
 
     public = survey.public_submissions()
     id_field = "crowdsourcing_submission.id"
-    submissions = extra_from_filters(public, id_field, survey, request.GET)
-    # If you want to sort based on rating, wire it up here.
-    if local_settings.PRE_REPORT:
-        pre_report = get_function(local_settings.PRE_REPORT)
-        submissions = pre_report(
-            submissions=submissions,
-            report=report_obj,
-            request=request)
-    if report_obj.featured:
-        submissions = submissions.filter(featured=True)
-    if report_obj.limit_results_to:
-        submissions = submissions[:report_obj.limit_results_to]
     if not report_obj.display_individual_results:
-        submissions = submissions.none()
+        submissions = public.none()
+    else:
+        submissions = extra_from_filters(public, id_field, survey, request.GET)
+        # If you want to sort based on rating, wire it up here.
+        if local_settings.PRE_REPORT:
+            pre_report = get_function(local_settings.PRE_REPORT)
+            submissions = pre_report(
+                submissions=submissions,
+                report=report_obj,
+                request=request)
+        if report_obj.featured:
+            submissions = submissions.filter(featured=True)
+        if report_obj.limit_results_to:
+            submissions = submissions[:report_obj.limit_results_to]
     paginator, page_obj = paginate_or_404(submissions, page)
 
     page_answers = get_all_answers(
@@ -547,6 +552,9 @@ def _survey_report(request, slug, report, page, templates):
     if pages_to_link[-1] < paginator.num_pages:
         pages_to_link = pages_to_link + [False, paginator.num_pages]
 
+    display_individual_results = all([
+        report_obj.display_individual_results,
+        archive_fields or (is_staff and fields)])
     context = dict(
         survey=survey,
         submissions=submissions,
@@ -559,6 +567,7 @@ def _survey_report(request, slug, report, page, templates):
         report=report_obj,
         page_answers=page_answers,
         is_public=is_public,
+        display_individual_results=display_individual_results,
         request=request)
 
     return render_to_response(templates, context, _rc(request))
@@ -594,6 +603,7 @@ def location_question_results(
     featured = limit_results_to = False
     if survey_report_slug:
         survey_report = get_object_or_404(SurveyReport.objects,
+                                          survey=question.survey,
                                           slug=survey_report_slug)
         featured = survey_report.featured
         limit_results_to = survey_report.limit_results_to
@@ -612,7 +622,7 @@ def location_question_results(
     answers = question.answer_set.filter(
         ~Q(latitude=None),
         ~Q(longitude=None),
-        submission__is_public=True)
+        submission__is_public=True).order_by("-submission__submitted_at")
     if featured:
         answers = answers.filter(submission__featured=True)
     answers = extra_from_filters(
